View source: R/package_files.R
Copies individual files from package to Quarto
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 | package_readme(
pkg_folder = "",
target = "",
file_names = c("readme.md"),
project_folder = "",
root_folder = here::here()
)
package_news(
pkg_folder = "",
target = "",
file_names = c("news.md", "news.Rmd"),
project_folder = "",
root_folder = here::here()
)
package_file_copy(
pkg_folder = "",
target = "project_folder",
file_names = c("name.md", "name.Rmd"),
override_name = NULL,
project_folder = "",
root_folder = here::here()
)
|
pkg_folder |
Path to the package's source code |
target |
Sub folder in |
file_names |
A vector of one or many file names. If it is multiple files the function will look for and use the first available. |
project_folder |
Sub folder in |
root_folder |
Base target Quarto folder. Defaults to current workspace. |
override_name |
File name of the output, in case the original file name needs to be changed. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.